create_sphere_mask: Create sphere mask for image

Description Usage Arguments Value Author(s) Examples

View source: R/SpatCorrImage.R

Description

Create sphere mask for image

Usage

1
create_sphere_mask(grids, center = rep(0, length = length(grids)), radius = 3)

Arguments

grids

a list of grids for each dimenion of the image.

center

the center of sphere. Default value is a vector of zeros.

radius

a postive number indicates the size of the neighborhood.

Value

an array with logical values

Author(s)

Jian Kang <jiankang@umich.edu>

Examples

1
sphere_mask = create_sphere_mask(list(1:10,1:10,1:10))

kangjian2016/SpatCorrImage documentation built on Oct. 22, 2021, 1:21 a.m.