find_image_neighbors: Find the neighbors for each voxels in images

Description Usage Arguments Value Author(s) Examples

View source: R/SpatCorrImage.R

Description

Find the neighbors for each voxels in images

Usage

1
find_image_neighbors(grids, d = NULL, radius = 1)

Arguments

grids

a vector of grids or a list of grids for each dimenion of the image.

d

the dimension of the image. When grids is a vector, d should be specified. Default is NULL.

radius

the size of neighborhood.

Value

a list object contains two matrices: idx and dist. idx contains the neighbor indices of each voxel in each row. dist contains the distances between neighbors and the voxel in each row.

Author(s)

Jian Kang <jiankang@umich.edu>

Examples

1
nb <- find_image_neighbors(1:10,d=3)

kangjian2016/SpatCorrImage documentation built on Oct. 22, 2021, 1:21 a.m.