Description Usage Arguments Value Author(s) Examples
View source: R/SpatCorrImage.R
Create sphere mask for image
1 | create_sphere_mask(grids, center = rep(0, length = length(grids)), radius = 3)
|
grids |
a list of grids for each dimenion of the image. |
center |
the center of sphere. Default value is a vector of zeros. |
radius |
a postive number indicates the size of the neighborhood. |
an array with logical values
Jian Kang <jiankang@umich.edu>
1 | sphere_mask = create_sphere_mask(list(1:10,1:10,1:10))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.