Description Usage Arguments Value Author(s) Examples
View source: R/SpatCorrImage.R
Find the neighbors for each voxels in images
1 | find_image_neighbors(grids, d = NULL, radius = 1)
|
grids |
a vector of grids or a list of grids for each dimenion of the image. |
d |
the dimension of the image. When |
radius |
the size of neighborhood. |
a list object contains two matrices: idx and dist.
idx contains the neighbor indices of each voxel in each row.
dist contains the distances between neighbors and the voxel in each row.
Jian Kang <jiankang@umich.edu>
1 | nb <- find_image_neighbors(1:10,d=3)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.