Description Usage Arguments Value Author(s) Examples
View source: R/SpatCorrImage.R
Spatial kernel smoothing for images
1 2 3 4 5 6 7 8 | spatial_kernel_smooth(
img,
grids = NULL,
mask = NULL,
neighbors = NULL,
radius = 3,
n_cor = 0.9
)
|
img |
an array for image. |
grids |
a list of grids for each dimension of the image. |
mask |
an array for mask |
neighbors |
a list object contains two matrices: |
radius |
a positive number for the size of neighborhood. Only use when neighbors is NULL. |
n_cor |
a positive correlation value between 0 and 1 to control the smoothness. A lager value generates a smoother image. |
Smoothed images with the same dimensions of the raw images.
Jian Kang <jiankang@umich.edu>
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.